/*
 * This file is part of the Liquid project.
 * It is header file of class DevOrientation, which reads and processes
 * data from accelerometer.
 *
 * Copyright (C) 2009 Kirpichonock K.N. <kirpiche@cs.karelia.ru>
 * Copyright (C) 2009 Volkov A.A. <volkov@cs.karelia.ru>
 * Copyright (C) 2009 Dmitriev V.V. <vdmitrie@cs.karelia.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */
//! An Accelerometer module.
/*!
  This class gets a data from accelerometer and processes it.
*/

#ifndef DEVORIENTATION_H
#define DEVORIENTATION_H

#include <QObject>
#include <QTimer>
#include <QWidget>
#include <QVector3D>
#include <QString>
#include <error_handler/errorhandler.h>

#define G 9.8
#define PI 3.141592653589

class devOrientation : public QWidget
{
  Q_OBJECT

public:
    ErrorHandler *eh;
    //! A constructor.
    devOrientation(ErrorHandler *errorHandler = 0);
    int timerID;
    void stopTimer();
    bool disabled;

protected:
    void timerEvent(QTimerEvent *);

public slots:
    void mceOrientationSlot(const QString &rotation, const QString &stand, const QString &face, int x, int y, int z);

signals:
    //! Signal, which generates when acceleration is splitted on 3 axises.
    void dataProcessed(QVector3D);

private:
    QString data; /*!< Contains a string with values of acceleration from sensor. */
    QString x; /*!< A value of acceleration on the X axis. */
    QString y; /*!< A value of acceleration on the Y axis. */
    QString z; /*!< A value of acceleration on the Z axis. */
    float fx;
    float fy;
    float fz;

};

#endif // DEVORIENTATION_H
